@@ -88,6 +88,7 @@ public Q_SLOTS:
     bool isLidClosed() const;
     bool isLidPresent() const;
     bool isActionSupported(const QString &actionName);
+    bool hasDualGpu() const;
 
 Q_SIGNALS:
     void coreReady();
@@ -109,6 +110,8 @@ private:
 
     friend class Action;
 
+    bool m_hasDualGpu;
+
     BackendInterface *m_backend;
 
     QDBusServiceWatcher *m_notificationsWatcher;
